﻿using System;
using System.Linq;
using System.Threading.Tasks;

namespace CookieBinge3
{
    public class AccountService : IDisposable
    {
        private static string _accountId;
        private static string _deviceName;
        public static string AccountId { get { return _accountId; } }
        public static string DeviceName { get { return _deviceName; } }
        public async Task<string> RegisterNewAccountAsync(string name, string deviceName)
        {
            var cloudService = new BingeCloudService();
            string newId = await cloudService.RegisterAccount(name);
            var account=StoreAccount(name, newId,deviceName);
            return account.AccountDisplay;
        }

        private static Account StoreAccount(string name, string newId, string deviceName)
        {
            using (var context = new BingeContext(BingeService.options))
            {
                var account=new Account { Name = name, Id = Guid.Parse(newId), Created = DateTime.Now.ToString(), DeviceName = deviceName };
                context.Accounts.Add(account);
                context.SaveChanges();
                _accountId = account.Id.ToString();
                _deviceName = deviceName;
                return account;
            }

        }
        public static Account GetAccount()
        {
            using (var context = new BingeContext(BingeService.options))
            {
                var account= context.Accounts.FirstOrDefault();
                _accountId = account?.Id.ToString();
                _deviceName = account?.DeviceName;
                return account;
            }
        }

        //retrieve id using name and shortid
        public static async Task<string> BindDeviceToAccount(string name, string shortId,string deviceName)
        {
            using (var cloudService = new BingeCloudService())
            {
                //user needs to type in name and shortid
                string accountId = await cloudService.GetAccountIdAsync(name, shortId);
                if (accountId != null)
                {
                    var account = StoreAccount(name, accountId, deviceName);
                    return account.AccountDisplay;
                }
                else
                { return null; }
            }
        }

        public void Dispose()
        {
        }
    }
}
