﻿using Newtonsoft.Json;
using SDKTemplate;
using System;
using System.Collections.Generic;
using System.Threading;
using System.Threading.Tasks;
using Windows.Data.Json;
using Windows.Web.Http;

namespace CookieBinge3
{
    public class BingeCloudService:IDisposable
    {
        struct StoreScoreDto
        {
            public string userId;
            public string userName;
            public string deviceName;
            public string dateTime;
            public string score;
            public string worthit;
            
            public StoreScoreDto(string userid, string userName, string deviceName,
                DateTime dateTime, int score, bool worthit)
            {
                this.userId = userid;
                this.userName = userName;
                this.deviceName = deviceName;
                this.dateTime = dateTime.ToString();
                this.score = score.ToString();
                this.worthit = worthit.ToString();
            }
        }

        public async Task<string> RegisterAccount(string name)
        {
            var jsonValue = JsonValue.Parse("{\"name\":\"" + name + "\"}");
            var account= await CallCookieBingeFunctionAsync<AccountViewModel>("Register", jsonValue);
            return account.Id;
        }
    

        public async Task<string> GetAccountIdAsync(string name, string shortId)
        {
            var uriMethod = $"GetAccountId\\{name}\\{shortId}";
            return await CallCookieBingeFunctionAsync<dynamic>(uriMethod);
        }

        public async void SendBingeToCloudAsync(int count, bool worthIt, DateTime timeOccurred)
        {
            var storeScore = new StoreScoreDto(AccountService.AccountId, "Julie", AccountService.DeviceName, timeOccurred, count, worthIt);
            var jsonScore = JsonConvert.SerializeObject(storeScore);
            var jsonValueScore = JsonValue.Parse(jsonScore);
            var results = await CallCookieBingeFunctionAsync<string>("StoreScores", jsonValueScore);
        }

        public async Task<List<ScoreViewModel>> GetTopGlobalScores()
        {
            var results= await CallCookieBingeFunctionAsync<List<ScoreViewModel>>("GetTop5GlobalUserScores");
            return results;
        }

        public async Task<List<ScoreViewModel>> GetUserTopScores()
        {
            var results = await CallCookieBingeFunctionAsync<List<ScoreViewModel>>($"GetUserScores\\{AccountService.AccountId}");
            return results;
        }

        private async Task<T> CallCookieBingeFunctionAsync<T>(string apiMethod)
        {
             return await CallCookieBingeFunctionAsync<T>(apiMethod, null);
        }

        private async Task<T> CallCookieBingeFunctionAsync<T>(string apiMethod, JsonValue jsonValue)
        {
            var httpClient = new HttpClient();
            var uri = new Uri("https://cookiebinge.azurewebsites.net/api/" + apiMethod);
            var httpContent = jsonValue != null ? new HttpJsonContent(jsonValue): null;
            var cts = new CancellationTokenSource();
            HttpResponseMessage response = await httpClient.PostAsync(uri, httpContent).AsTask(cts.Token); //.GetResults();
            string body = await response.Content.ReadAsStringAsync(); //.GetResults();
            T deserializedBody = JsonConvert.DeserializeObject<T>(body);
            return deserializedBody;
        }
       public void Dispose()
        { }
    }
}
