﻿using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.EntityFrameworkCore;

namespace CookieBinge3
{
    public static class BingeService
    {
         public static DbContextOptions options;
      
        public static  void RecordBinge(int count, bool worthIt)
        {
            var binge = new CookieBinge
            {
                HowMany = count,
                WorthIt = worthIt,
                TimeOccurred = DateTime.Now
            };

            using (var context = new BingeContext(options))
            {
                context.Binges.Add(binge);
                context.SaveChanges();
            }

            using (var cloudService = new BingeCloudService())
            {
                cloudService.SendBingeToCloudAsync(count, worthIt, binge.TimeOccurred);
            }
        }
       
        public static IEnumerable<CookieBinge> GetRecentBinges(int numberToRetrieve)
        {
            using (var context = new BingeContext(options))
            {
                return context.Binges
                  .OrderByDescending(b => b.TimeOccurred)
                  .Take(numberToRetrieve).ToList();
            }
        }

        public static void SetDbFilePathAndMigrate(string dbFilePath)
        {
            options = new DbContextOptionsBuilder().UseSqlite($"Data source={dbFilePath}").Options;
            using (var db = new BingeContext(options))
            {
                
                  db.Database.Migrate();
            }
        }

        public static void ClearHistory()
        {
            using (var context = new BingeContext(options))
            {
                context.Database.EnsureDeleted();
                context.Database.EnsureCreated();
            }
        }
    }
}