﻿using System;
using System.Threading.Tasks;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Input;

namespace CookieBinge3
{
    public sealed partial class MainPage 
    {
        private readonly BingeViewModel _binge;
        private readonly ScoreViewModel _score;

        public MainPage()
        {
            DataContext = this;
            InitializeComponent();
            CreateAccountButton.IsEnabled = false;
            EnterAccountButton.IsEnabled = false;
            _binge = new BingeViewModel();
            _score = new ScoreViewModel();
            NomText.Visibility = Visibility.Collapsed;
            // Refresh bing list after a new binge is added
            _binge.BingeCompleted += s => { ReloadHistory(); };
            BingePane.DataContext = _binge;
            AccountPane.DataContext = _score;
            //check if stored account exists, if so display that, if not display buttons
            DisplayStoredAccountAndTopScoresIfExists();
           
        }

        private async void DisplayStoredAccountAndTopScoresIfExists()
        {
            var account = AccountService.GetAccount();
            if (account != null)
            {
                await ReloadScores();
                EnterAccountButton.Visibility = Visibility.Collapsed;
                CreateAccountButton.Visibility = Visibility.Collapsed;
                AccountInfoText.Text = account.AccountDisplay;
                AccountInfoText.Visibility = Visibility.Visible;

            }
            else
            {
                CreateAccountButton.IsEnabled = true;
                EnterAccountButton.IsEnabled = true;
            }
        }

        private void Page_Loaded(object sender, RoutedEventArgs e)
        {
            ReloadHistory();
        }

        private void ReloadHistory()
        {
            BingeList.ItemsSource = BingeService.GetRecentBinges(5);
        }
        private async Task ReloadScores()
        {
            using (var cloudService = new BingeCloudService())
            {
                  YourScoresList.ItemsSource = await cloudService.GetUserTopScores();
               
                  GlobalScoresList.ItemsSource = await cloudService.GetTopGlobalScores();
            }
        }


        private void Play_Tapped(object sender, TappedRoutedEventArgs e)
        {
            _binge.StartNewBinge();
        }


        private void WorthIt_Click(object sender, RoutedEventArgs e)
        {
            _binge.StoreBinge(true);
        }

        private void NotWorthIt_Click(object sender, RoutedEventArgs e)
        {
            _binge.StoreBinge(false);
        }

        private void CookieImage_PointerPressed(object sender, PointerRoutedEventArgs e)
        {

            if (_binge.Binging)
            {
                ((Image)sender).CapturePointer(e.Pointer);

                var pt = e.GetCurrentPoint(BingeGrid);
                NomText.Margin = new Thickness(pt.Position.X, pt.Position.Y, 0, 0);

                NomText.Visibility = Visibility.Visible;
                _binge.HandleClick();
            }
        }

        private void CookieImage_PointerReleased(object sender, PointerRoutedEventArgs e)
        {
            ((Image)sender).ReleasePointerCapture(e.Pointer);

            NomText.Visibility = Visibility.Collapsed;
        }


        private void ClearHistory_Click(object sender, RoutedEventArgs e)
        {
            BingeService.ClearHistory();
            ReloadHistory();
        }

        private void CreateAccount_Click(object sender, RoutedEventArgs e)
        {
            EnterName.Visibility = Visibility.Visible;
            EnterAccountButton.Visibility = Visibility.Collapsed;
            CreateAccountButton.Visibility = Visibility.Collapsed;
        }
        private async void RegisterButton_Click(object sender, RoutedEventArgs e)
        {
            using (var accountService=new AccountService())
            {
                string accountDisplay =  await accountService.RegisterNewAccountAsync(UserNameText.Text.TrimEnd(),DeviceNameText.Text.TrimEnd());
                AccountInfoText.Text = accountDisplay;
                AccountInfoText.Visibility = Visibility.Visible;
                EnterName.Visibility = Visibility.Collapsed;
            }
        }
        private void EnterAccount_Click(object sender, RoutedEventArgs e)
        {
            EnterExistingAccount.Visibility = Visibility.Visible;
            EnterAccountButton.Visibility = Visibility.Collapsed;
            CreateAccountButton.Visibility = Visibility.Collapsed;
        }
        private async void SignIn_Click(object sender, RoutedEventArgs e)
        {
                string accountDisplay=await AccountService.BindDeviceToAccount(
                  AccountUserNameText.Text.TrimEnd(),
                  AccountIdText.Text.TrimEnd(),
                  AccountDeviceNameText.Text.TrimEnd());
            if (accountDisplay != null)
            {
                AccountInfoText.Text = accountDisplay;
                AccountInfoText.Visibility = Visibility.Visible;
                EnterExistingAccount.Visibility = Visibility.Collapsed;
            }
   
        }

        private async void refreshScores_Click(object sender, RoutedEventArgs e)
        {
            await ReloadScores();
        }
       
    }

}